Documentation
¶
Overview ¶
Package testutil provides shared test helpers for integration tests.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApplyMigrations ¶
ApplyMigrations is a test helper that runs all pending migrations.
func ConnectAndMigrate ¶
ConnectAndMigrate connects to the test database and applies all pending migrations. It returns a ready-to-use pool.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.